Payu
====

Payu is a climate model workflow management tool for supercomputing
environments.

Payu is currently only configured for use on computing clusters maintained by
NCI (National Computing Infrastructure) in Australia.

See `the documentation`_ for more details.

.. _the documentation: http://payu.readthedocs.org/en/latest/
